@@ -275,7 +275,7 @@
 #' 
 procD.lm <- function(f1, iter = 999, seed=NULL, RRPP = TRUE, 
                      SS.type = c("I", "II", "III"),
-                     effect.type = c("SS", "MS", "Rsq", "F", "cohen"),
+                     effect.type = c("F", "cohenf", "SS", "MS", "Rsq"),
                      int.first = FALSE,  Cov = NULL, data=NULL, print.progress = TRUE, ...){
   
   if(is.null(data)) {
